Learn R Programming

perturbR (version 0.1.3)

perturbR-package: Perturb Networks

Description

The perturbR function incrementally perturbs networks (using the rewireR function) and compares the resulting rewired networks with the orignal. These comparisons aid in understanding the stability of the cluster solution.

Arguments